CheckboxPickerDialog<T> class

This is a support widget that returns an Dialog with checkboxes as a Widget. It is designed to be used in the showDialog method of other fields.

Inheritance
Implemented types

Constructors

CheckboxPickerDialog({String? title, required List<T> items, required List<T>? selectedItems, Transformer<T>? transformer, Color? headerColor, Color? headerTextColor, Color? backgroundColor, Color? buttonTextColor, double? maxLongSide, double? maxShortSide, String? confirmText, bool cancelButtonVisible = true, String? cancelText, ValueChanged<List<T>>? onSelectionChanged, SelectAllConfig? selectAllConfig})

Properties

backgroundColor → Color?
The dialog background color (overrides theme)
final
buttonTextColor → Color?
The button text color (overrides theme)
final
cancelButtonVisible → bool
final
cancelText → String?
Text to display in the cancel button
final
confirmText → String?
Text to display in the confirm button
final
hashCode → int
The hash code for this object.
no setterinherited
headerColor → Color?
The dialog header color (overrides theme)
final
headerTextColor → Color?
The dialog header text color (overrides theme)
final
items → List<T>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLongSide → double?
Used to restrict how tall the dialog can be.
final
maxShortSide → double?
Used to restrict how wide the dialog can be.
final
onSelectionChanged → ValueChanged<List<T>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectAllConfig → SelectAllConfig?
final
selectedItems → List<T>?
final
title → String?
The title for the dialog box
final
transformer → Transformer<T>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CheckboxPickerDialog>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited